@@ -100,15 +100,24 @@ impl ReaderChild for VectorReaderService {
             .iter()
             .cloned()
             .map(AtomClause::key_prefix);
+        let paragraph_labels = request
+            .paragraph_labels
+            .iter()
+            .cloned()
+            .map(AtomClause::label);
         let mut formula = Formula::new();
         request
-            .tags
+            .field_labels
             .iter()
             .cloned()
             .map(AtomClause::label)
             .for_each(|c| formula.extend(c));
+
         if key_filters.len() > 0 {
-            formula.extend(CompoundClause::new(1, key_filters.collect()));
+            formula.extend(CompoundClause::new(key_filters.collect()));
+        }
+        for paragraph_label in paragraph_labels {
+            formula.extend(paragraph_label);
         }
 
         let search_request = (total_to_get, request, formula);
@@ -286,7 +295,6 @@ mod tests {
             paragraphs: HashMap::from([("DOC/KEY".to_string(), paragraphs)]),
             paragraphs_to_delete: vec![],
             sentences_to_delete: vec![],
-            relations_to_delete: vec![],
             relations: vec![],
             vectors: HashMap::default(),
             vectors_to_delete: HashMap::default(),
@@ -302,7 +310,7 @@ mod tests {
             id: "".to_string(),
             vector_set: "".to_string(),
             vector: vec![4.0, 6.0, 7.0],
-            tags: vec!["1".to_string()],
+            field_labels: vec!["1".to_string()],
             key_filters: vec!["DOC/KEY/1".to_string()],
             page_number: 0,
             result_per_page: 20,
@@ -368,7 +376,6 @@ mod tests {
             paragraphs: HashMap::from([("DOC/KEY".to_string(), paragraphs)]),
             paragraphs_to_delete: vec![],
             sentences_to_delete: vec![],
-            relations_to_delete: vec![],
             relations: vec![],
             vectors: HashMap::default(),
             vectors_to_delete: HashMap::default(),
@@ -383,7 +390,7 @@ mod tests {
             id: "".to_string(),
             vector_set: "".to_string(),
             vector: vec![4.0, 6.0, 7.0],
-            tags: vec!["1".to_string()],
+            field_labels: vec!["1".to_string()],
             page_number: 0,
             result_per_page: 20,
             with_duplicates: true,
@@ -396,7 +403,7 @@ mod tests {
             id: "".to_string(),
             vector_set: "".to_string(),
             vector: vec![4.0, 6.0, 7.0],
-            tags: vec!["1".to_string()],
+            field_labels: vec!["1".to_string()],
             page_number: 0,
             result_per_page: 20,
             with_duplicates: false,
@@ -412,7 +419,7 @@ mod tests {
             id: "".to_string(),
             vector_set: "".to_string(),
             vector: vec![4.0, 6.0, 7.0],
-            tags: vec!["1".to_string()],
+            field_labels: vec!["1".to_string()],
             page_number: 0,
             result_per_page: 20,
             with_duplicates: false,
@@ -428,7 +435,7 @@ mod tests {
             id: "".to_string(),
             vector_set: "".to_string(),
             vector: vec![4.0, 6.0],
-            tags: vec!["1".to_string()],
+            field_labels: vec!["1".to_string()],
             page_number: 0,
             result_per_page: 20,
             with_duplicates: false,
@@ -486,7 +493,6 @@ mod tests {
             paragraphs: HashMap::from([("DOC/KEY".to_string(), paragraphs)]),
             paragraphs_to_delete: vec![],
             sentences_to_delete: vec![],
-            relations_to_delete: vec![],
             relations: vec![],
             vectors: HashMap::default(),
             vectors_to_delete: HashMap::default(),
@@ -500,7 +506,7 @@ mod tests {
             id: "".to_string(),
             vector_set: "".to_string(),
             vector: vec![4.0, 6.0, 7.0],
-            tags: vec!["1".to_string()],
+            field_labels: vec!["1".to_string()],
             page_number: 0,
             result_per_page: 20,
             with_duplicates: true,
@@ -513,7 +519,7 @@ mod tests {
             id: "".to_string(),
             vector_set: "".to_string(),
             vector: vec![4.0, 6.0, 7.0],
-            tags: vec!["1".to_string()],
+            field_labels: vec!["1".to_string()],
             page_number: 0,
             result_per_page: 20,
             with_duplicates: false,
